@@ -118,6 +118,8 @@ public abstract class Stanza implements Serializable {
     protected volatile Map<ElementPath, List<PayloadTree>> payloads;
     
     protected int resendCount = 0;
+    
+    private Map<String, Object> channelAttributes = new HashMap<String, Object>();
 
     /**
      * Initializes a new {@link Stanza}.
@@ -616,6 +618,14 @@ public abstract class Stanza implements Serializable {
         }
         setPayloads(copy);
     }
+    
+    public Object getChannelAttribute(String name) {
+    	return channelAttributes.get(name);
+    }
+    
+    public void setChannelAttribute(String name, Object o) {
+    	channelAttributes.put(name, o);
+    }
 
     /**
      * Write a payload to the PayloadTree identified by the ElementPath. There is only one tree for the default elements which only contains
